add

Function add 

pub fn add(checksum: [u8; 2], bytes: &[u8]) -> [u8; 2]
Updates a checksum to reflect that the bytes bytes have been added.

add implements the algorithm described in [RFC 1624 Eqn. 3] for the special case where the previous data was all zeroes. The first byte must be at an even number offset in the checksummed data, or else a zero byte must be prepended.